@@ -550,7 +550,7 @@ class AngularClientRendererTestCase(TestCase):
                 import { Observable } from 'rxjs';
                 import * as _ from 'underscore';
 
-                import { HttpService } from '@lily/http';
+                import { HttpService } from '../../http.service';
 
                 import * as X from './paths.models';
 
@@ -821,8 +821,6 @@ class AngularClientRendererTestCase(TestCase):
                 import { Injectable, Injector } from '@angular/core';
                 import { Observable } from 'rxjs';
 
-                import { Options } from '@lily/http';
-
                 import * as X from '../domains/index';
 
                 @Injectable()
@@ -892,7 +890,8 @@ class AngularClientRendererTestCase(TestCase):
                   * OVERWRITTEN
                   */
 
-                import { NgModule } from '@angular/core';
+                import { NgModule, ModuleWithProviders } from '@angular/core';
+                import { HttpClientModule } from '@angular/common/http';
 
                 /** Domains */
                 import { CardsDomain } from './domains/cards/index';
@@ -901,8 +900,10 @@ class AngularClientRendererTestCase(TestCase):
 
                 /** Services */
                 import { APIService } from './services/api.service';
+                import { HttpService, Config } from './http.service';
 
                 @NgModule({
+                    imports: [HttpClientModule],
                     providers: [
                         // Domains
                         CardsDomain,
@@ -911,7 +912,19 @@ class AngularClientRendererTestCase(TestCase):
 
                         // Facade
                         APIService,
+                        HttpService,
                     ]
                 })
-                export class ClientModule {}
+                export class ClientModule {
+                  static forRoot(config: Config): ModuleWithProviders<ClientModule> {
+
+                    return {
+
+                      ngModule: ClientModule,
+
+                      providers: [{ provide: 'COSPHERE_CLIENT_CONFIG_TOKEN', useValue: config }]
+
+                    };
+                  }
+                }
             ''', 0)  # noqa
